# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, List
from pydantic import BaseModel, Field, conlist
from access_server_connector.models.rule_preset_out import RulePresetOut

class RulePresetListOut(BaseModel):
    """
    All of a portal's presets, flat and grouped for the editor.  ``presets_by_type`` partitions them: each ResourceType key plus an ``any`` bucket for type-agnostic presets. When offering presets for an event, the editor shows ``presets_by_type[event] + presets_by_type[any]``.  # noqa: E501
    """
    presets: conlist(RulePresetOut) = Field(...)
    presets_by_type: Dict[str, conlist(RulePresetOut)] = Field(...)
    __properties = ["presets", "presets_by_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RulePresetListOut:
        """Create an instance of RulePresetListOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item in self.presets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['presets'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in presets_by_type (dict of array)
        _field_dict_of_array = {}
        if self.presets_by_type:
            for _key in self.presets_by_type:
                if self.presets_by_type[_key] is not None:
                    _field_dict_of_array[_key] = [
                        _item.to_dict() for _item in self.presets_by_type[_key]
                    ]
            _dict['presets_by_type'] = _field_dict_of_array
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RulePresetListOut:
        """Create an instance of RulePresetListOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RulePresetListOut.parse_obj(obj)

        _obj = RulePresetListOut.parse_obj({
            "presets": [RulePresetOut.from_dict(_item) for _item in obj.get("presets")] if obj.get("presets") is not None else None,
            "presets_by_type": {
                _k: [RulePresetOut.from_dict(_item) for _item in _v] if _v is not None else None
                for _k, _v in obj["presets_by_type"].items()
            }
            if obj.get("presets_by_type") is not None
            else None
        })
        return _obj


