# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictInt, conlist
from access_server_connector.models.member_ownership_out import MemberOwnershipOut

class PackageMemberOut(BaseModel):
    """
    One member of a package with ALL their ownership reasons — the deduped roster.  A member holding the package via several grants (rebuy, manual + order, …) appears once, with every grant nested; the ledger view (…/ownerships) shows them per grant.  # noqa: E501
    """
    member_id: StrictInt = Field(...)
    is_effective: StrictBool = Field(...)
    ownerships: conlist(MemberOwnershipOut) = Field(...)
    __properties = ["member_id", "is_effective", "ownerships"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PackageMemberOut:
        """Create an instance of PackageMemberOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in ownerships (list)
        _items = []
        if self.ownerships:
            for _item in self.ownerships:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ownerships'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PackageMemberOut:
        """Create an instance of PackageMemberOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PackageMemberOut.parse_obj(obj)

        _obj = PackageMemberOut.parse_obj({
            "member_id": obj.get("member_id"),
            "is_effective": obj.get("is_effective"),
            "ownerships": [MemberOwnershipOut.from_dict(_item) for _item in obj.get("ownerships")] if obj.get("ownerships") is not None else None
        })
        return _obj


