# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.rule_preset_list_out import RulePresetListOut  # noqa: E501

class TestRulePresetListOut(unittest.TestCase):
    """RulePresetListOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RulePresetListOut:
        """Test RulePresetListOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RulePresetListOut`
        """
        model = RulePresetListOut()  # noqa: E501
        if include_optional:
            return RulePresetListOut(
                presets = [
                    access_server_connector.models.rule_preset_out.RulePresetOut(
                        id = 56, 
                        name = '', 
                        resource_type = null, 
                        access_mode = 'available', 
                        unlock_delay_ms = 56, 
                        unlock_align_cron = '', 
                        access_duration_ms = 56, 
                        starts_at = 56, 
                        ends_at = 56, 
                        window_cron = '', 
                        window_duration_ms = 56, 
                        timezone = '', 
                        binding = 'single', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
                presets_by_type = {
                    'key' : [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ]
                    }
            )
        else:
            return RulePresetListOut(
                presets = [
                    access_server_connector.models.rule_preset_out.RulePresetOut(
                        id = 56, 
                        name = '', 
                        resource_type = null, 
                        access_mode = 'available', 
                        unlock_delay_ms = 56, 
                        unlock_align_cron = '', 
                        access_duration_ms = 56, 
                        starts_at = 56, 
                        ends_at = 56, 
                        window_cron = '', 
                        window_duration_ms = 56, 
                        timezone = '', 
                        binding = 'single', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
                presets_by_type = {
                    'key' : [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ]
                    },
        )
        """

    def testRulePresetListOut(self):
        """Test RulePresetListOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
