# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.package_member_out import PackageMemberOut  # noqa: E501

class TestPackageMemberOut(unittest.TestCase):
    """PackageMemberOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PackageMemberOut:
        """Test PackageMemberOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PackageMemberOut`
        """
        model = PackageMemberOut()  # noqa: E501
        if include_optional:
            return PackageMemberOut(
                member_id = 56,
                is_effective = True,
                ownerships = [
                    access_server_connector.models.member_ownership_out.MemberOwnershipOut(
                        member_id = 56, 
                        reason_id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        is_effective = True, 
                        granted_at = 56, 
                        is_test = True, 
                        period_end = 56, 
                        grace_until = 56, )
                    ]
            )
        else:
            return PackageMemberOut(
                member_id = 56,
                is_effective = True,
                ownerships = [
                    access_server_connector.models.member_ownership_out.MemberOwnershipOut(
                        member_id = 56, 
                        reason_id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        is_effective = True, 
                        granted_at = 56, 
                        is_test = True, 
                        period_end = 56, 
                        grace_until = 56, )
                    ],
        )
        """

    def testPackageMemberOut(self):
        """Test PackageMemberOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
