# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.rule_presets_api import RulePresetsApi  # noqa: E501


class TestRulePresetsApi(unittest.IsolatedAsyncioTestCase):
    """RulePresetsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = RulePresetsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_v1_rule_presets_post(self) -> None:
        """Test case for create_v1_rule_presets_post

        Create a reusable rule preset  # noqa: E501
        """
        pass

    async def test_delete_preset_v1_rule_presets_preset_id_delete(self) -> None:
        """Test case for delete_preset_v1_rule_presets_preset_id_delete

        Delete a rule preset  # noqa: E501
        """
        pass

    async def test_get_preset_v1_rule_presets_preset_id_get(self) -> None:
        """Test case for get_preset_v1_rule_presets_preset_id_get

        Get one rule preset  # noqa: E501
        """
        pass

    async def test_list_presets_v1_rule_presets_get(self) -> None:
        """Test case for list_presets_v1_rule_presets_get

        List the portal's rule presets (flat + grouped per resource type)  # noqa: E501
        """
        pass

    async def test_update_preset_v1_rule_presets_preset_id_patch(self) -> None:
        """Test case for update_preset_v1_rule_presets_preset_id_patch

        Edit a rule preset (name / type hint / body)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
